@@ -65,8 +65,9 @@ print STDERR "\n\n\n\n" if $debug;
 MULTI_TEST:
 # This query returns MANY pages of results:
 $iTest++;
+$sQuery = '"Bo'.'ss Na'.'ss"';
 $oSearch->native_query(
-                       WWW::Search::escape_query('"Bo'.'ss Na'.'ss"'),
+                       WWW::Search::escape_query($sQuery),
                       { 'search_debug' => $debug, },
                       );
 $oSearch->maximum_to_retrieve(149); # 3 pages
@@ -75,7 +76,7 @@ $iResults = scalar(@aoResults);
 # print STDERR " + got $iResults results for Bos","s Na","ss\n";
 if (($iResults < 101))
   {
-  print STDERR " --- got $iResults results for '\"Bos","s Na","ss\"', but expected 101..\n";
+  print STDERR " --- got $iResults results for $sQuery, but expected 101..\n";
   print STDOUT 'not ';
   }
 print "ok $iTest\n";
@@ -85,16 +86,18 @@ GUI_TEST:
 # This query returns 1 page of results:
 $iTest++;
 # $debug = 9;
+$sQuery = 'Ma'.'rtin AND Thu'.'rn AND Bi'.'ble AND Galo'.'ob';
 $oSearch->gui_query(
-                    WWW::Search::escape_query('Ma'.'rtin Thu'.'rn Galo'.'ob'),
+                    WWW::Search::escape_query($sQuery),
                       { 'search_debug' => $debug, },
                    );
-$oSearch->maximum_to_retrieve(30);
+$oSearch->maximum_to_retrieve(20);
 @aoResults = $oSearch->results();
 $iResults = scalar(@aoResults);
-if (($iResults < 1) || (9 < $iResults))
+print STDERR " + got $iResults GUI results for $sQuery, expected 1..10\n" if $debug;
+if (($iResults < 1) || (10 < $iResults))
   {
-  print STDERR " --- got $iResults GUI results for 'Ma","rtin AND Thu","rn AND Galo","ob', but expected 1..9\n";
+  print STDERR " --- got $iResults GUI results for $sQuery, but expected 1..10\n";
   print STDOUT 'not ';
   }
 print "ok $iTest\n";
